@@ -1,5 +1,4 @@
 from . import mock_dns
-
 from .utils import execute_script
 
 
@@ -7,5 +6,5 @@ def setup_module():
     mock_dns.activate()
 
 
-def test(url):
-    execute_script('test_dns.twill', initial_url=url)
+def test(url: str):
+    execute_script("test_dns.twill", initial_url=url)
